@@ -1,7 +1,7 @@
 package POE::Component::IKC::Client;
 
 ############################################################
-# $Id: Client.pm,v 1.10 2001/09/06 23:13:42 fil Exp $
+# $Id: Client.pm,v 1.12 2002/10/17 03:13:05 fil Exp $
 # Based on refserver.perl
 # Contributed by Artur Bergman <artur@vogon-solutions.com>
 # Revised for 0.06 by Rocco Caputo <troc@netrus.net>
@@ -24,7 +24,7 @@ use Carp;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_client);
-$VERSION = '0.1302';
+$VERSION = '0.14';
 
 sub DEBUG { 0 }
 
@@ -106,8 +106,8 @@ sub _start {
 
     DEBUG && print "Client starting.\n";
     my %wheel_p=(
-        SuccessState   => 'connected',    # generating this event on connection
-        FailureState   => 'error'         # generating this event on error
+        SuccessEvent   => 'connected',    # generating this event on connection
+        FailureEvent   => 'error'         # generating this event on error
     );
                                         # create a socket factory
     if($parms->{unix}) {
