@@ -1,13 +1,13 @@
 package POE::Component::IKC::Responder;
 
 ############################################################
-# $Id: Responder.pm,v 1.13 2001/10/27 03:14:45 fil Exp $
+# $Id: Responder.pm,v 1.15 2002/05/02 19:35:54 fil Exp $
 # Based on tests/refserver.perl
 # Contributed by Artur Bergman <artur@vogon-solutions.com>
 # Revised for 0.06 by Rocco Caputo <troc@netrus.net>
 # Turned into a module by Philp Gwyn <fil@pied.nu>
 #
-# Copyright 1999,2001 Philip Gwyn.  All rights reserved.
+# Copyright 1999,2001,2002 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -25,7 +25,7 @@ use POE::Component::IKC::Specifier;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_responder $ikc);
-$VERSION = '0.1302';
+$VERSION = '0.14';
 
 sub DEBUG { 0 }
 
@@ -49,7 +49,7 @@ sub spawn
                       register unregister default register_local
                       publish retract subscribe unsubscribe
                       published
-                      monitor shutdown 
+                      monitor inform_monitors shutdown 
                       do_you_have ping sig_INT
                     )]);
     return 1;
@@ -65,7 +65,7 @@ sub _start
     DEBUG and warn "$$: Responder started.\n";
     $kernel->alias_set('IKC');              # allow it to be called by name
 
-#    $kernel->signal(INT=>'sig_INT');
+#    $kernel->signal(INT=>'sig_INT');  # sig_INT is empty, so don't bother
     $ikc=POE::Component::IKC::Responder::Object->new($kernel, $session);
     $heap->{self}=$ikc;
 }
@@ -282,9 +282,19 @@ sub ping
 # User wants to kill process / kernel
 sub sig_INT
 {
-    my ($heap)=$_[HEAP];
+    my ($heap, $kernel)=@_[HEAP, KERNEL];
     DEBUG && warn "$$: Responder::sig_INT\n";
-    return 1;
+    $kernel->sig_handled();
+    return;
+}
+
+
+#----------------------------------------------------
+# User wants to kill process / kernel
+sub inform_monitors
+{
+    my ($heap)=$_[HEAP];
+    $heap->{self}->inform_monitors(@_[ARG0..$#_]);
 }
 
 
@@ -309,7 +319,7 @@ use Data::Dumper;
 
 sub DEBUG { 0 }
 sub DEBUG2 { 0 }
-
+sub DEBUGM { DEBUG or 0 }
 sub new
 {
     my($package, $kernel, $session)=@_;
@@ -877,39 +887,41 @@ sub call
 ##############################################################################
 # publish/retract/subscribe mechanism of setting up foreign sessions
 
+sub _aliases
+{
+    my($kernel, $session)=@_;
+    return $session unless ref $session; # make sure it's an object
+
+    if($kernel->can('alias_list')) {
+            # post-0.15 we register as all aliases for session
+        my @a=$kernel->alias_list($session->ID);
+        return @a if @a;
+    } 
+
+    # pre-0.15 means that we register as session ID... which is less
+    # then useful
+    return $session->ID;
+}
+
 #----------------------------------------------------
 sub publish
 {
     my($self, $session, $states)=@_;
-    if(ref $session) {                  # make sure it's not an object
-        my $kernel=$self->{poe_kernel};
-        if($kernel->can('alias_list')) {
-            my $has_aliases=0;
-
-            # post-0.15 we register as all aliases for session
-            foreach my $alias ($kernel->alias_list($session->ID)) {
-                $self->publish($alias, $states);
-                $has_aliases=1;
-            }
-            return if $has_aliases;
-        } 
-
-        # pre-0.15 means that we register as session ID... which is less
-        # then useful
-        $session=$session->ID;
-    }
     unless($session) {
         carp "You must specify the session that publishes these states";
         return 0;
     }
+    my @aliases =_aliases($self->{poe_kernel}, $session);
 
-    $self->{'local'}{$session}||={};
-    my $p=$self->{'local'}{$session};
+    foreach my $alias (@aliases) {
+        $self->{'local'}{$alias}||={};
+        my $p=$self->{'local'}{$alias};
 
-    die "\$states isn't an array ref" unless ref($states) eq 'ARRAY';
-    foreach my $q (@$states) {
-        DEBUG and warn "Published poe:$session/$q\n";
-        $p->{$q}=1;
+        die "\$states isn't an array ref" unless ref($states) eq 'ARRAY';
+        foreach my $q (@$states) {
+            DEBUG and warn "Published poe:$alias/$q\n";
+            $p->{$q}=1;
+        }
     }
     return 1;
 }
@@ -939,43 +951,26 @@ sub retract
 {
     my($self, $session, $states)=@_;
 
-    my $sid=$session;
-
-    if(ref $session) {                  # make sure it's not an object
-
-        my $kernel=$self->{poe_kernel};
-        if($kernel->can('alias_list')) {
-            # post 0.15 we register as all aliases for session
-            foreach my $alias ($kernel->alias_list($session->ID)) {
-                $self->retract($alias, $states);
-            }
-            return;
-        } 
-        else {
-            # pre 0.15 means that we register as session ID... which is less
-            # then useful
-            $sid=$session->ID;
-        }
-    }
-
-    unless($sid) {
+    unless($session) {
         warn "You must specify the session that publishes these states";
         return 0;
     }
+    my @aliases=_aliases($self->{poe_kernel}, $session);
+    foreach my $alias (@aliases) {
+        unless($self->{'local'}{$alias}) {
+            warn "Session '$session' ($alias) didn't publish anything, can't retract";
+            return 0;
+        }
 
-    unless($self->{'local'}{$sid}) {
-        warn "Session '$session' ($sid) didn't publish anything, can't retract";
-        return 0;
-    }
-
-    if($states) {
-        my $p=$self->{'local'}{$sid};
-        foreach my $q (@$states) {
-            delete $p->{$q};
+        if($states) {
+            my $p=$self->{'local'}{$alias};
+            foreach my $q (@$states) {
+                delete $p->{$q};
+            }
+            delete $self->{'local'}{$alias} unless keys %$p;
+        } else {
+            delete $self->{'local'}{$alias};
         }
-        delete $self->{'local'}{$sid} unless %$p;
-    } else {
-        delete $self->{'local'}{$sid};
     }
     return 1;
 }
@@ -1103,12 +1098,17 @@ sub _subscribe_receipt
     else {                                      # accepted
         $ses=specifier_parse($ses);
         die "Bad state" unless $ses;
+        my($kernel)=@{$self}{qw(poe_kernel)};
 
         DEBUG and warn "Create proxy for ", specifier_name($ses), "\n";
         my $proxy=POE::Component::IKC::Proxy->spawn(
                       $ses->{kernel}, $ses->{session},
-                      sub { $self->inform_monitors($rid, 'subscribe', $ses)},
-                      sub { $self->inform_monitors($rid, 'unsubscribe', $ses)}
+                      sub { $kernel->post(IKC=>'inform_monitors', 
+                                $rid, 'subscribe', $ses)},
+                      # 2002/04 monitor_stop is called in _stop, but we can't
+                      # can't post() from _stop, so we call() ourself
+                      sub { $kernel->call(IKC=>'inform_monitors', 
+                                $rid, 'unsubscribe', $ses)},
                     );
 
         push @{$self->{remote}{$ses->{kernel}}}, $proxy;
@@ -1193,11 +1193,12 @@ sub monitor
 
     if($states) {
         $states->{__name}=$name;
-        DEBUG and warn "$$: Session ID=$sender is monitoring $spec\n";
+        DEBUGM and 
+            warn "$$: Session $sender is monitoring $spec\n";
         $self->{monitors}{$spec}{$sender}=$states;
     }
     else {
-        DEBUG and warn "$$: Session ID=$sender is neglecting $spec\n";
+        DEBUGM and warn "$$: Session $sender is neglecting $spec\n";
         delete $self->{monitors}{$spec}{$sender};
     }
     return;
@@ -1214,10 +1215,11 @@ sub inform_monitors
     my($self, $rid, $event, @params)=@_;
     my($kernel)=@{$self}{qw(poe_kernel)};
     $rid=specifier_part($rid, 'kernel') unless $rid eq '*';
-    croak "No kernel in $_[1]!" unless $rid;
+    croak "$$: No kernel in $_[1]!" unless $rid;
 
     my $real=1 if $self->{channel}{$rid};
-    DEBUG and warn "$rid is", ($real ? '' : "n't"), " real\n";
+    DEBUGM and 
+        warn "$$: $rid is", ($real ? '' : "n't"), " real\n";
 
     # got to be a better way of doing this...
     my @todo=($rid);
@@ -1227,7 +1229,8 @@ sub inform_monitors
 
         my $ms=$self->{monitors}{$n};
         unless($ms and %$ms) {
-            DEBUG and warn "$$: No sessions care about $n/$event\n";
+            DEBUGM and 
+                warn "$$: No sessions care about $event $n\n";
             next;
         }
 
@@ -1237,7 +1240,8 @@ sub inform_monitors
             my $e=$states->{$event};
             next unless $e;
 
-            DEBUG and warn "$$: Informing Session ID=$sender/$e about $n/$event\n";
+            DEBUGM and 
+                warn "$$: Informing Session $sender/$e about $n/$event\n";
                 # ARG0 = what Session called the kernel
                 # ARG1 = what kernel calls the kernel
                 # ARG2 = true if kernel is name, false if alias
@@ -1248,6 +1252,7 @@ sub inform_monitors
         }
     }
 
+    # $rid might be an alias to something else, inform about those as well
     if($self->{channel}{$rid}) {
         foreach my $ra (@{$self->{alias}{$rid}}) {
             $self->inform_monitors($ra, $event, @params);
@@ -1680,9 +1685,7 @@ Subscription receipt timeout is currently set to 120 seconds.
 =head2 C<unsubscribe>
 
 Reverse of the C<subscribe> method.  However, it is currently not
-implemented.
-
-
+documented well.
 
 =head2 C<ping>
 
@@ -1924,6 +1927,15 @@ L<POE>, L<POE::Component::IKC::Server>, L<POE::Component::IKC::Client>
 
 
 $Log: Responder.pm,v $
+Revision 1.15  2002/05/02 19:35:54  fil
+Updated Chanages.
+Merged alias listing for publish/subtract
+Moved version
+
+Revision 1.14  2002/05/02 19:00:32  fil
+Fixed inform_monitor comming from IKC::Proxy/_stop.  We can't post()
+from _stop, so method call is turned into ->call().
+
 Revision 1.13  2001/10/27 03:14:45  fil
 Now works with latest CVS version of POE (0.1701)
 
