@@ -1,13 +1,13 @@
 package POE::Component::IKC::Server;
 
 ############################################################
-# $Id: Server.pm,v 1.13 2001/10/27 03:14:45 fil Exp $
+# $Id: Server.pm,v 1.16 2002/10/17 03:13:05 fil Exp $
 # Based on refserver.perl and preforkedserver.perl
 # Contributed by Artur Bergman <artur@vogon-solutions.com>
 # Revised for 0.06 by Rocco Caputo <troc@netrus.net>
 # Turned into a module by Philp Gwyn <fil@pied.nu>
 #
-# Copyright 1999,2001 Philip Gwyn.  All rights reserved.
+# Copyright 1999,2001,2002 Philip Gwyn.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -27,7 +27,7 @@ require Exporter;
 
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_server);
-$VERSION = '0.1303';
+$VERSION = '0.14';
 
 sub DEBUG { 0 }
 sub DEBUG_USR2 { 1 }
@@ -131,8 +131,8 @@ sub _start
     my $n='unknown';
     my %wheel_p=(
         Reuse          => 'yes',        # and allow immediate reuse of the port
-        SuccessState   => 'accept',     # generating this event on connection
-        FailureState   => 'error'       # generating this event on error
+        SuccessEvent   => 'accept',     # generating this event on connection
+        FailureEvent   => 'error'       # generating this event on error
     );
     if($params->{unix}) {
         $n="unix:$params->{unix}";
@@ -592,7 +592,7 @@ sub sig_CHLD
     my ($kernel, $heap, $signal, $pid, $status, $fake) =
                 @_[KERNEL, HEAP, ARG0, ARG1, ARG2, ARG3];
 
-    return 0 if $heap->{"is a child"};
+    return if $heap->{"is a child"};
 
     if($heap->{children}) {
                                 # if it was one of ours; fork another
@@ -611,7 +611,7 @@ sub sig_CHLD
         }
     }
                                         # don't handle terminal signals
-    return 0;
+    return;
 }
 
 #------------------------------------------------------------------------------
@@ -629,13 +629,13 @@ sub sig_INT
         warn "$$ SIGINT\n";
         $heap->{'die'}=1;
         $kernel->delay('waste_time');   # kill this event
-        return 1;
+        $kernel->sig_handled();
     } else {
         delete $heap->{wheel};
-        return 1;
+        $kernel->sig_handled();
     }    
-                                        # don't handle terminal signals
-    return 0;
+    # don't handle terminal signals
+    return;
 }
 
 sub check_kernel
@@ -679,6 +679,8 @@ sub sig_USR2
     $pid||='';
     check_kernel($kernel, $heap->{'is a child'}, 1);
     warn "$$: signal $signal $pid\n";
+    $kernel->sig_handled();
+    return;
 }
 
 
